#!/usr/bin/env cwl-runner
cwlVersion: v1.2
class: Workflow

requirements:
  ScatterFeatureRequirement: {}
  StepInputExpressionRequirement: {}
  InlineJavascriptRequirement: {}

inputs:
    IndexInput: File[]
    sampleRecord:
        type:
          type: array
          items:
            type: record
            fields:
              readsOfOneSample:
                type: File[]
              sampleName:
                type: string?
    isSingle: boolean
    FragmentLength: double?
    StandardDeviation: double?
    BootstrapSamples: int?
    resultsFolder: string

steps:
    index:
        run: kallisto-index.cwl
        in:
            InputFiles: IndexInput
            IndexName:
                source: IndexInput
                valueFrom: $(self[0].nameroot)
        out: [index]

    quant:
        run: kallisto-quant.cwl
        scatter: [InputReads, QuantOutfolder]
        scatterMethod: dotproduct
        in:
            InputReads:
                source: sampleRecord
                valueFrom: $(self.readsOfOneSample)
            QuantOutfolder:
                source: sampleRecord
                valueFrom: $(self.sampleName)
            Index: index/index
            isSingle: isSingle
            FragmentLength: FragmentLength
            StandardDeviation: StandardDeviation
            BootstrapSamples: BootstrapSamples
        out: [outFolder]

    collectResults:
        run: ./yield-dirInDestination.cwl
        scatter: inDir
        in:
            inDir: quant/outFolder
            destinationDir: resultsFolder
        out: [outDir]

outputs:
  finalOut:
    type: Directory[]
    outputSource: collectResults/outDir
